@@ -156,7 +156,7 @@ class FileDict(Fragment):
         super(FileDict, self).__init__()
 
     def is_expired(self):
-        expired=any(f.expired for f in self.files.itervalues())
+        return any(f.expired for f in self.files.itervalues())
 
     def get_content(self):
         if not self._content:
